@@ -29,10 +29,12 @@
 Support for building and installing Clang, implemented as an easyblock.
 
 @author: Dmitri Gribenko (National Technical University of Ukraine "KPI")
+@author: Ward Poelmans (Ghent University)
 """
 
 import os
 import shutil
+from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.cmakemake import CMakeMake
 from easybuild.framework.easyblock import EasyBlock
@@ -48,6 +50,8 @@ class EB_Clang(CMakeMake):
     def extra_options():
         extra_vars = [
             ('assertions', [True, "Enable assertions.  Helps to catch bugs in Clang.  (default: True)", CUSTOM]),
+            ('build_targets', [["X86"], "Build targets for LLVM. Possible values: all, AArch64, ARM, CppBackend, Hexagon, " +
+                               "Mips, MBlaze, MSP430, NVPTX, PowerPC, Sparc, SystemZ, X86, XCore (default: X86)", CUSTOM]),
         ]
         return EasyBlock.extra_options(extra_vars)
 
@@ -61,6 +65,9 @@ class EB_Clang(CMakeMake):
         self.llvm_obj_dir_stage3 = None
         self.make_parallel_opts = ""
 
+    def check_readiness_step(self):
+        """Fail early on RHEL 5.x and derivatives because of known bug in libc."""
+        super(EB_Clang, self).check_readiness_step()
         # RHEL 5.x have a buggy libc.  Building stage 2 will fail.
         if get_os_name() in ['redhat', 'RHEL', 'centos', 'SL'] and get_os_version().startswith('5.'):
             self.log.error(("Can not build clang on %s v5.x: libc is buggy, building stage 2 will fail.  " +
@@ -90,9 +97,14 @@ class EB_Clang(CMakeMake):
 
         # Move other directories into the LLVM tree.
         src_dirs = {
-            'clang-%s.src' % self.version: os.path.join(self.llvm_src_dir, 'tools', 'clang'),
             'compiler-rt-%s.src' % self.version: os.path.join(self.llvm_src_dir, 'projects', 'compiler-rt')
         }
+        if LooseVersion(self.version) < LooseVersion('3.3'):
+            clang_src_dir = 'clang-%s.src' % self.version
+        else:
+            clang_src_dir = 'cfe-%s.src' % self.version
+        src_dirs[clang_src_dir] = os.path.join(self.llvm_src_dir, 'tools', 'clang')
+
         for tmp in self.src:
             for (dir, new_path) in src_dirs.items():
                 if tmp['name'].startswith(dir):
@@ -125,6 +137,8 @@ class EB_Clang(CMakeMake):
         else:
             self.cfg['configopts'] += "-DLLVM_ENABLE_ASSERTIONS=OFF "
 
+        self.cfg['configopts'] += '-DLLVM_TARGETS_TO_BUILD="%s" ' % ';'.join(self.cfg['build_targets'])
+
         if self.cfg['parallel']:
             self.make_parallel_opts = "-j %s" % self.cfg['parallel']
 
