@@ -58,7 +58,11 @@ class EB_CUDA(Binary):
                  # this question is only asked if CUDA tools are already available system-wide
                  r"Would you like to remove all CUDA files under .*? (yes/no/abort): ": "no",
                 }
-        noqanda = [r"Installation Complete"]
+        noqanda = [
+            r"^Configuring",
+            r"Installation Complete",
+            r".* -> .*",
+        ]
 
         # patch install script to handle Q&A autonomously
         patch_perl_script_autoflush(os.path.join(self.builddir, install_script))
@@ -76,7 +80,7 @@ class EB_CUDA(Binary):
         custom_paths = {
             'files': ["bin/%s" % x for x in ["fatbinary", "nvcc", "nvlink", "ptxas"]] +
                      ["%s/lib%s.so" % (x, y) for x in ["lib", "lib64"] for y in ["cublas", "cudart", "cufft",
-                                                                                 "curand", "cusparse", "npp"]] +
+                                                                                 "curand", "cusparse"]] +
                      ["open64/bin/nvopencc"],
             'dirs': ["include"],
         }
