@@ -31,6 +31,7 @@ EasyBuild support for building and installing GCC, implemented as an easyblock
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
 @author: Toon Willems (Ghent University)
+@author: Ward Poelmans (Ghent University)
 """
 
 import re
@@ -58,6 +59,9 @@ class EB_GCC(ConfigureMake):
 
         self.stagedbuild = False
 
+        # unset some environment variables that are known to may cause nasty build errors when bootstrapping
+        self.cfg.update('unwanted_env_vars', ['CPATH', 'C_INCLUDE_PATH', 'CPLUS_INCLUDE_PATH', 'OBJC_INCLUDE_PATH', 'LIBRARY_PATH'])
+
     @staticmethod
     def extra_options():
         extra_vars = [
