@@ -25,7 +25,11 @@
 """
 EasyBuild support for building and installing Python, implemented as an easyblock
 
-@authors: Stijn De Weirdt, Dries Verdegem, Kenneth Hoste, Pieter De Baets, Jens Timmerman (Ghent University)
+@author: Stijn De Weirdt (Ghent University)
+@author: Dries Verdegem (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+@author: Pieter De Baets (Ghent University)
+@author: Jens Timmerman (Ghent University)
 """
 
 import os
@@ -36,7 +40,7 @@ from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.filetools import run_cmd
 
 
-EXTS_FILTER_PYTHON_PACKAGES = ('python -c "import %(name)s"', "")
+EXTS_FILTER_PYTHON_PACKAGES = ('python -c "import %(ext_name)s"', "")
 
 
 class EB_Python(ConfigureMake):
